@@ -468,7 +468,8 @@ class MyBuddyCommandGenerator(MyCobotCommandGenerator):
         _speed = speed
         encoders_data = []
         if id == 0:
-            encoders_data = (_encoders[0:6] + speed[0:6] + _encoders[6:12] + speed[6:12] + _encoders[-2:] + speed[-2:])
+            encoders_data = (_encoders[0:7] + speed[0:7] + _encoders[7:14] + speed[7:14] + _encoders[-1:] + speed[-1:])
+            print(encoders_data)
             return self._mesg(ProtocolCode.SET_ENCODERS, _id, encoders_data)
         if id == 1 or id == 2:
             return self._mesg(ProtocolCode.SET_ENCODERS, _id, _encoders, _speed)
@@ -669,7 +670,7 @@ class MyBuddyCommandGenerator(MyCobotCommandGenerator):
     # Atom IO
     
 
-    def set_pin_mode(self, id, pin_no, pin_mode):
+    def set_tool_pin_mode(self, id, pin_no, pin_mode):
         """Set the state mode of the specified pin in atom.
 
         Args:
@@ -679,7 +680,7 @@ class MyBuddyCommandGenerator(MyCobotCommandGenerator):
         """
         return self._mesg(ProtocolCode.SET_PIN_MODE, id, pin_no, pin_mode)
 
-    def set_digital_output(self, id, pin_no, pin_signal):
+    def set_tool_digital_output(self, id, pin_no, pin_signal):
         """Set atom IO output level
 
         Args:
@@ -689,7 +690,7 @@ class MyBuddyCommandGenerator(MyCobotCommandGenerator):
         """
         return self._mesg(ProtocolCode.SET_DIGITAL_OUTPUT, id, pin_no, pin_signal)
 
-    def get_digital_input(self, id, pin_no):
+    def get_tool_digital_input(self, id, pin_no):
         """singal value
 
         Args:
@@ -698,7 +699,7 @@ class MyBuddyCommandGenerator(MyCobotCommandGenerator):
         """
         return self._mesg(ProtocolCode.GET_DIGITAL_INPUT, id, pin_no, has_reply=True)
 
-    def set_pwm_output(self, id, channel, frequency, pin_val):
+    def set_tool_pwm_output(self, id, channel, frequency, pin_val):
         """PWM control
 
         Args:
@@ -760,7 +761,7 @@ class MyBuddyCommandGenerator(MyCobotCommandGenerator):
         """
         return self._mesg(ProtocolCode.IS_GRIPPER_MOVING, id, has_reply=True)
 
-    def set_color(self, id, r=0, g=0, b=0):
+    def set_tool_color(self, id, r=0, g=0, b=0):
         """Set the light color on the top of the robot arm.
 
         Args:
@@ -1124,4 +1125,4 @@ class MyBuddyCommandGenerator(MyCobotCommandGenerator):
     
     # def init_iic(self):
     #     from smbus2 import SMBus
-    #     i2c = SMBus(1)   # 1 代表 /dev/i2c-1
+    #     i2c = SMBus(1)   # 1 代表 /dev/i2c-1
\ No newline at end of file
